@@ -10,6 +10,7 @@ pub use point::*;
 pub use point3::*;
 pub use ptr::*;
 pub use rect::*;
+pub use scalar::*;
 pub use size::*;
 pub use sized::*;
 pub use vec::*;
@@ -42,6 +43,7 @@ mod point3;
 mod point;
 pub(crate) mod ptr;
 mod rect;
+mod scalar;
 mod size;
 mod sized;
 mod vec;
