@@ -4,16 +4,18 @@
 // support non-POD types as union fields
 
 use std::{
-	marker::PhantomData,
 	ffi::c_void,
+	marker::PhantomData,
+	mem::MaybeUninit,
 };
+
 use crate::{Error, Result as CrateResult, types::Unit};
 
 #[repr(C)]
 pub struct Result<S, O = S> {
 	pub error_code: i32,
 	pub error_msg: *mut c_void,
-	pub result: S,
+	pub result: MaybeUninit<S>,
 	_p: PhantomData<O>,
 }
 
@@ -21,7 +23,7 @@ impl<S: Into<O>, O> Result<S, O> {
 	#[inline]
 	pub fn into_result(self) -> CrateResult<O> {
 		if self.error_msg.is_null() {
-			Ok(self.result.into())
+			Ok(unsafe { self.result.assume_init() }.into())
 		} else {
 			Err(Error::new(self.error_code, unsafe { crate::templ::receive_string(self.error_msg as *mut String) }))
 		}
