@@ -9,7 +9,7 @@
 )]
 //! # silhouette based 3D object tracking
 //! 
-//! implements "RAPID-a video rate object tracker" [harris1990rapid](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_harris1990rapid) with the dynamic control point extraction of [drummond2002real](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_drummond2002real)
+//! implements "RAPID-a video rate object tracker" [harris1990rapid](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_harris1990rapid) with the dynamic control point extraction of [drummond2002real](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_drummond2002real)
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
 	pub use { super::TrackerConst, super::Tracker, super::RapidConst, super::Rapid, super::OLSTrackerConst, super::OLSTracker, super::GOSTrackerConst, super::GOSTracker };
@@ -33,7 +33,10 @@ pub fn convert_correspondencies(cols: &dyn core::ToInputArray, src_locations: &d
 	output_array_arg!(pts2d);
 	input_output_array_arg!(pts3d);
 	input_array_arg!(mask);
-	let ret = unsafe { sys::cv_rapid_convertCorrespondencies_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputOutputArrayR_const__InputArrayR(cols.as_raw__InputArray(), src_locations.as_raw__InputArray(), pts2d.as_raw__OutputArray(), pts3d.as_raw__InputOutputArray(), mask.as_raw__InputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_convertCorrespondencies_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputOutputArrayR_const__InputArrayR(cols.as_raw__InputArray(), src_locations.as_raw__InputArray(), pts2d.as_raw__OutputArray(), pts3d.as_raw__InputOutputArray(), mask.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -50,7 +53,10 @@ pub fn draw_correspondencies(bundle: &mut dyn core::ToInputOutputArray, cols: &d
 	input_output_array_arg!(bundle);
 	input_array_arg!(cols);
 	input_array_arg!(colors);
-	let ret = unsafe { sys::cv_rapid_drawCorrespondencies_const__InputOutputArrayR_const__InputArrayR_const__InputArrayR(bundle.as_raw__InputOutputArray(), cols.as_raw__InputArray(), colors.as_raw__InputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_drawCorrespondencies_const__InputOutputArrayR_const__InputArrayR_const__InputArrayR(bundle.as_raw__InputOutputArray(), cols.as_raw__InputArray(), colors.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -63,7 +69,10 @@ pub fn draw_correspondencies(bundle: &mut dyn core::ToInputOutputArray, cols: &d
 pub fn draw_search_lines(img: &mut dyn core::ToInputOutputArray, locations: &dyn core::ToInputArray, color: core::Scalar) -> Result<()> {
 	input_output_array_arg!(img);
 	input_array_arg!(locations);
-	let ret = unsafe { sys::cv_rapid_drawSearchLines_const__InputOutputArrayR_const__InputArrayR_const_ScalarR(img.as_raw__InputOutputArray(), locations.as_raw__InputArray(), &color) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_drawSearchLines_const__InputOutputArrayR_const__InputArrayR_const_ScalarR(img.as_raw__InputOutputArray(), locations.as_raw__InputArray(), &color, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -84,13 +93,16 @@ pub fn draw_wireframe(img: &mut dyn core::ToInputOutputArray, pts2d: &dyn core::
 	input_output_array_arg!(img);
 	input_array_arg!(pts2d);
 	input_array_arg!(tris);
-	let ret = unsafe { sys::cv_rapid_drawWireframe_const__InputOutputArrayR_const__InputArrayR_const__InputArrayR_const_ScalarR_int_bool(img.as_raw__InputOutputArray(), pts2d.as_raw__InputArray(), tris.as_raw__InputArray(), &color, typ, cull_backface) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_drawWireframe_const__InputOutputArrayR_const__InputArrayR_const__InputArrayR_const_ScalarR_int_bool(img.as_raw__InputOutputArray(), pts2d.as_raw__InputArray(), tris.as_raw__InputArray(), &color, typ, cull_backface, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// Extract control points from the projected silhouette of a mesh
 /// 
-/// see [drummond2002real](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_drummond2002real) Sec 2.1, Step b
+/// see [drummond2002real](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_drummond2002real) Sec 2.1, Step b
 /// ## Parameters
 /// * num: number of control points
 /// * len: search radius (used to restrict the ROI)
@@ -111,7 +123,10 @@ pub fn extract_control_points(num: i32, len: i32, pts3d: &dyn core::ToInputArray
 	input_array_arg!(tris);
 	output_array_arg!(ctl2d);
 	output_array_arg!(ctl3d);
-	let ret = unsafe { sys::cv_rapid_extractControlPoints_int_int_const__InputArrayR_const__InputArrayR_const__InputArrayR_const__InputArrayR_const_SizeR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(num, len, pts3d.as_raw__InputArray(), rvec.as_raw__InputArray(), tvec.as_raw__InputArray(), k.as_raw__InputArray(), &imsize, tris.as_raw__InputArray(), ctl2d.as_raw__OutputArray(), ctl3d.as_raw__OutputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_extractControlPoints_int_int_const__InputArrayR_const__InputArrayR_const__InputArrayR_const__InputArrayR_const_SizeR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(num, len, pts3d.as_raw__InputArray(), rvec.as_raw__InputArray(), tvec.as_raw__InputArray(), k.as_raw__InputArray(), &imsize, tris.as_raw__InputArray(), ctl2d.as_raw__OutputArray(), ctl3d.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -129,7 +144,10 @@ pub fn extract_line_bundle(len: i32, ctl2d: &dyn core::ToInputArray, img: &dyn c
 	input_array_arg!(img);
 	output_array_arg!(bundle);
 	output_array_arg!(src_locations);
-	let ret = unsafe { sys::cv_rapid_extractLineBundle_int_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(len, ctl2d.as_raw__InputArray(), img.as_raw__InputArray(), bundle.as_raw__OutputArray(), src_locations.as_raw__OutputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_extractLineBundle_int_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(len, ctl2d.as_raw__InputArray(), img.as_raw__InputArray(), bundle.as_raw__OutputArray(), src_locations.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -147,11 +165,14 @@ pub fn find_correspondencies(bundle: &dyn core::ToInputArray, cols: &mut dyn cor
 	input_array_arg!(bundle);
 	output_array_arg!(cols);
 	output_array_arg!(response);
-	let ret = unsafe { sys::cv_rapid_findCorrespondencies_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(bundle.as_raw__InputArray(), cols.as_raw__OutputArray(), response.as_raw__OutputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_findCorrespondencies_const__InputArrayR_const__OutputArrayR_const__OutputArrayR(bundle.as_raw__InputArray(), cols.as_raw__OutputArray(), response.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
-/// High level function to execute a single rapid [harris1990rapid](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_harris1990rapid) iteration
+/// High level function to execute a single rapid [harris1990rapid](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_harris1990rapid) iteration
 /// 
 /// 1. @ref extractControlPoints
 /// 2. @ref extractLineBundle
@@ -182,11 +203,14 @@ pub fn rapid(img: &dyn core::ToInputArray, num: i32, len: i32, pts3d: &dyn core:
 	input_array_arg!(k);
 	input_output_array_arg!(rvec);
 	input_output_array_arg!(tvec);
-	let ret = unsafe { sys::cv_rapid_rapid_const__InputArrayR_int_int_const__InputArrayR_const__InputArrayR_const__InputArrayR_const__InputOutputArrayR_const__InputOutputArrayR_doubleX(img.as_raw__InputArray(), num, len, pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), k.as_raw__InputArray(), rvec.as_raw__InputOutputArray(), tvec.as_raw__InputOutputArray(), rmsd) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_rapid_rapid_const__InputArrayR_int_int_const__InputArrayR_const__InputArrayR_const__InputArrayR_const__InputOutputArrayR_const__InputOutputArrayR_doubleX(img.as_raw__InputArray(), num, len, pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), k.as_raw__InputArray(), rvec.as_raw__InputOutputArray(), tvec.as_raw__InputOutputArray(), rmsd, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
-/// implements "Global optimal searching for textureless 3D object tracking" [wang2015global](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_wang2015global)
+/// implements "Global optimal searching for textureless 3D object tracking" [wang2015global](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_wang2015global)
 pub trait GOSTrackerConst: crate::rapid::TrackerConst {
 	fn as_raw_GOSTracker(&self) -> *const c_void;
 
@@ -205,14 +229,17 @@ impl dyn GOSTracker + '_ {
 	pub fn create(pts3d: &dyn core::ToInputArray, tris: &dyn core::ToInputArray, hist_bins: i32, sobel_thesh: u8) -> Result<core::Ptr<dyn crate::rapid::OLSTracker>> {
 		input_array_arg!(pts3d);
 		input_array_arg!(tris);
-		let ret = unsafe { sys::cv_rapid_GOSTracker_create_const__InputArrayR_const__InputArrayR_int_unsigned_char(pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), hist_bins, sobel_thesh) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_rapid_GOSTracker_create_const__InputArrayR_const__InputArrayR_int_unsigned_char(pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), hist_bins, sobel_thesh, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::rapid::OLSTracker>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 }
 /// implements "Optimal local searching for fast and robust textureless 3D object tracking in highly
-/// cluttered backgrounds" [seo2013optimal](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_seo2013optimal)
+/// cluttered backgrounds" [seo2013optimal](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_seo2013optimal)
 pub trait OLSTrackerConst: crate::rapid::TrackerConst {
 	fn as_raw_OLSTracker(&self) -> *const c_void;
 
@@ -231,7 +258,10 @@ impl dyn OLSTracker + '_ {
 	pub fn create(pts3d: &dyn core::ToInputArray, tris: &dyn core::ToInputArray, hist_bins: i32, sobel_thesh: u8) -> Result<core::Ptr<dyn crate::rapid::OLSTracker>> {
 		input_array_arg!(pts3d);
 		input_array_arg!(tris);
-		let ret = unsafe { sys::cv_rapid_OLSTracker_create_const__InputArrayR_const__InputArrayR_int_unsigned_char(pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), hist_bins, sobel_thesh) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_rapid_OLSTracker_create_const__InputArrayR_const__InputArrayR_int_unsigned_char(pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), hist_bins, sobel_thesh, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::rapid::OLSTracker>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -253,7 +283,10 @@ impl dyn Rapid + '_ {
 	pub fn create(pts3d: &dyn core::ToInputArray, tris: &dyn core::ToInputArray) -> Result<core::Ptr<dyn crate::rapid::Rapid>> {
 		input_array_arg!(pts3d);
 		input_array_arg!(tris);
-		let ret = unsafe { sys::cv_rapid_Rapid_create_const__InputArrayR_const__InputArrayR(pts3d.as_raw__InputArray(), tris.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_rapid_Rapid_create_const__InputArrayR_const__InputArrayR(pts3d.as_raw__InputArray(), tris.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::rapid::Rapid>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -276,13 +309,19 @@ pub trait Tracker: core::AlgorithmTrait + crate::rapid::TrackerConst {
 		input_array_arg!(k);
 		input_output_array_arg!(rvec);
 		input_output_array_arg!(tvec);
-		let ret = unsafe { sys::cv_rapid_Tracker_compute_const__InputArrayR_int_int_const__InputArrayR_const__InputOutputArrayR_const__InputOutputArrayR_const_TermCriteriaR(self.as_raw_mut_Tracker(), img.as_raw__InputArray(), num, len, k.as_raw__InputArray(), rvec.as_raw__InputOutputArray(), tvec.as_raw__InputOutputArray(), &termcrit) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_rapid_Tracker_compute_const__InputArrayR_int_int_const__InputArrayR_const__InputOutputArrayR_const__InputOutputArrayR_const_TermCriteriaR(self.as_raw_mut_Tracker(), img.as_raw__InputArray(), num, len, k.as_raw__InputArray(), rvec.as_raw__InputOutputArray(), tvec.as_raw__InputOutputArray(), &termcrit, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn clear_state(&mut self) -> Result<()> {
-		let ret = unsafe { sys::cv_rapid_Tracker_clearState(self.as_raw_mut_Tracker()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_rapid_Tracker_clearState(self.as_raw_mut_Tracker(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
