@@ -26,14 +26,20 @@ pub mod prelude {
 pub fn emdl1(signature1: &dyn core::ToInputArray, signature2: &dyn core::ToInputArray) -> Result<f32> {
 	input_array_arg!(signature1);
 	input_array_arg!(signature2);
-	let ret = unsafe { sys::cv_EMDL1_const__InputArrayR_const__InputArrayR(signature1.as_raw__InputArray(), signature2.as_raw__InputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_EMDL1_const__InputArrayR_const__InputArrayR(signature1.as_raw__InputArray(), signature2.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// Complete constructor
 #[inline]
 pub fn create_affine_transformer(full_affine: bool) -> Result<core::Ptr<dyn crate::shape::AffineTransformer>> {
-	let ret = unsafe { sys::cv_createAffineTransformer_bool(full_affine) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createAffineTransformer_bool(full_affine, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::AffineTransformer>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -43,7 +49,10 @@ pub fn create_affine_transformer(full_affine: bool) -> Result<core::Ptr<dyn crat
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_chi_histogram_cost_extractor(n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	let ret = unsafe { sys::cv_createChiHistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createChiHistogramCostExtractor_int_float(n_dummies, default_cost, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -54,7 +63,10 @@ pub fn create_chi_histogram_cost_extractor(n_dummies: i32, default_cost: f32) ->
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_emd_histogram_cost_extractor(flag: i32, n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	let ret = unsafe { sys::cv_createEMDHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createEMDHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -64,7 +76,10 @@ pub fn create_emd_histogram_cost_extractor(flag: i32, n_dummies: i32, default_co
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_emdl1_histogram_cost_extractor(n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	let ret = unsafe { sys::cv_createEMDL1HistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createEMDL1HistogramCostExtractor_int_float(n_dummies, default_cost, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -74,7 +89,10 @@ pub fn create_emdl1_histogram_cost_extractor(n_dummies: i32, default_cost: f32)
 /// * rank_prop: 0.6f
 #[inline]
 pub fn create_hausdorff_distance_extractor(distance_flag: i32, rank_prop: f32) -> Result<core::Ptr<dyn crate::shape::HausdorffDistanceExtractor>> {
-	let ret = unsafe { sys::cv_createHausdorffDistanceExtractor_int_float(distance_flag, rank_prop) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createHausdorffDistanceExtractor_int_float(distance_flag, rank_prop, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::HausdorffDistanceExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -85,7 +103,10 @@ pub fn create_hausdorff_distance_extractor(distance_flag: i32, rank_prop: f32) -
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_norm_histogram_cost_extractor(flag: i32, n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	let ret = unsafe { sys::cv_createNormHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createNormHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -100,7 +121,10 @@ pub fn create_norm_histogram_cost_extractor(flag: i32, n_dummies: i32, default_c
 /// * transformer: createThinPlateSplineShapeTransformer()
 #[inline]
 pub fn create_shape_context_distance_extractor(n_angular_bins: i32, n_radial_bins: i32, inner_radius: f32, outer_radius: f32, iterations: i32, comparer: &core::Ptr<dyn crate::shape::HistogramCostExtractor>, transformer: &core::Ptr<dyn crate::shape::ShapeTransformer>) -> Result<core::Ptr<dyn crate::shape::ShapeContextDistanceExtractor>> {
-	let ret = unsafe { sys::cv_createShapeContextDistanceExtractor_int_int_float_float_int_const_Ptr_HistogramCostExtractor_R_const_Ptr_ShapeTransformer_R(n_angular_bins, n_radial_bins, inner_radius, outer_radius, iterations, comparer.as_raw_PtrOfHistogramCostExtractor(), transformer.as_raw_PtrOfShapeTransformer()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createShapeContextDistanceExtractor_int_int_float_float_int_const_Ptr_HistogramCostExtractor_R_const_Ptr_ShapeTransformer_R(n_angular_bins, n_radial_bins, inner_radius, outer_radius, iterations, comparer.as_raw_PtrOfHistogramCostExtractor(), transformer.as_raw_PtrOfShapeTransformer(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::ShapeContextDistanceExtractor>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -111,7 +135,10 @@ pub fn create_shape_context_distance_extractor(n_angular_bins: i32, n_radial_bin
 /// * regularization_parameter: 0
 #[inline]
 pub fn create_thin_plate_spline_shape_transformer(regularization_parameter: f64) -> Result<core::Ptr<dyn crate::shape::ThinPlateSplineShapeTransformer>> {
-	let ret = unsafe { sys::cv_createThinPlateSplineShapeTransformer_double(regularization_parameter) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createThinPlateSplineShapeTransformer_double(regularization_parameter, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { core::Ptr::<dyn crate::shape::ThinPlateSplineShapeTransformer>::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -122,7 +149,10 @@ pub trait AffineTransformerConst: crate::shape::ShapeTransformerConst {
 
 	#[inline]
 	fn get_full_affine(&self) -> Result<bool> {
-		let ret = unsafe { sys::cv_AffineTransformer_getFullAffine_const(self.as_raw_AffineTransformer()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_AffineTransformer_getFullAffine_const(self.as_raw_AffineTransformer(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -133,7 +163,10 @@ pub trait AffineTransformer: crate::shape::AffineTransformerConst + crate::shape
 
 	#[inline]
 	fn set_full_affine(&mut self, full_affine: bool) -> Result<()> {
-		let ret = unsafe { sys::cv_AffineTransformer_setFullAffine_bool(self.as_raw_mut_AffineTransformer(), full_affine) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_AffineTransformer_setFullAffine_bool(self.as_raw_mut_AffineTransformer(), full_affine, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -156,7 +189,10 @@ pub trait EMDHistogramCostExtractorConst: crate::shape::HistogramCostExtractorCo
 
 	#[inline]
 	fn get_norm_flag(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_EMDHistogramCostExtractor_getNormFlag_const(self.as_raw_EMDHistogramCostExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_EMDHistogramCostExtractor_getNormFlag_const(self.as_raw_EMDHistogramCostExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -167,7 +203,10 @@ pub trait EMDHistogramCostExtractor: crate::shape::EMDHistogramCostExtractorCons
 
 	#[inline]
 	fn set_norm_flag(&mut self, flag: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_EMDHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_EMDHistogramCostExtractor(), flag) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_EMDHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_EMDHistogramCostExtractor(), flag, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -196,13 +235,19 @@ pub trait HausdorffDistanceExtractorConst: crate::shape::ShapeDistanceExtractorC
 
 	#[inline]
 	fn get_distance_flag(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_getDistanceFlag_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HausdorffDistanceExtractor_getDistanceFlag_const(self.as_raw_HausdorffDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_rank_proportion(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_getRankProportion_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HausdorffDistanceExtractor_getRankProportion_const(self.as_raw_HausdorffDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -218,7 +263,10 @@ pub trait HausdorffDistanceExtractor: crate::shape::HausdorffDistanceExtractorCo
 	/// (NORM_L1, NORM_L2).
 	#[inline]
 	fn set_distance_flag(&mut self, distance_flag: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_setDistanceFlag_int(self.as_raw_mut_HausdorffDistanceExtractor(), distance_flag) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HausdorffDistanceExtractor_setDistanceFlag_int(self.as_raw_mut_HausdorffDistanceExtractor(), distance_flag, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -230,7 +278,10 @@ pub trait HausdorffDistanceExtractor: crate::shape::HausdorffDistanceExtractorCo
 	/// * rankProportion: fractional value (between 0 and 1).
 	#[inline]
 	fn set_rank_proportion(&mut self, rank_proportion: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_setRankProportion_float(self.as_raw_mut_HausdorffDistanceExtractor(), rank_proportion) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HausdorffDistanceExtractor_setRankProportion_float(self.as_raw_mut_HausdorffDistanceExtractor(), rank_proportion, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -242,13 +293,19 @@ pub trait HistogramCostExtractorConst: core::AlgorithmTraitConst {
 
 	#[inline]
 	fn get_n_dummies(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_HistogramCostExtractor_getNDummies_const(self.as_raw_HistogramCostExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HistogramCostExtractor_getNDummies_const(self.as_raw_HistogramCostExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_default_cost(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_HistogramCostExtractor_getDefaultCost_const(self.as_raw_HistogramCostExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HistogramCostExtractor_getDefaultCost_const(self.as_raw_HistogramCostExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -262,19 +319,28 @@ pub trait HistogramCostExtractor: core::AlgorithmTrait + crate::shape::Histogram
 		input_array_arg!(descriptors1);
 		input_array_arg!(descriptors2);
 		output_array_arg!(cost_matrix);
-		let ret = unsafe { sys::cv_HistogramCostExtractor_buildCostMatrix_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_HistogramCostExtractor(), descriptors1.as_raw__InputArray(), descriptors2.as_raw__InputArray(), cost_matrix.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HistogramCostExtractor_buildCostMatrix_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_HistogramCostExtractor(), descriptors1.as_raw__InputArray(), descriptors2.as_raw__InputArray(), cost_matrix.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_n_dummies(&mut self, n_dummies: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_HistogramCostExtractor_setNDummies_int(self.as_raw_mut_HistogramCostExtractor(), n_dummies) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HistogramCostExtractor_setNDummies_int(self.as_raw_mut_HistogramCostExtractor(), n_dummies, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_default_cost(&mut self, default_cost: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_HistogramCostExtractor_setDefaultCost_float(self.as_raw_mut_HistogramCostExtractor(), default_cost) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_HistogramCostExtractor_setDefaultCost_float(self.as_raw_mut_HistogramCostExtractor(), default_cost, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -286,7 +352,10 @@ pub trait NormHistogramCostExtractorConst: crate::shape::HistogramCostExtractorC
 
 	#[inline]
 	fn get_norm_flag(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_NormHistogramCostExtractor_getNormFlag_const(self.as_raw_NormHistogramCostExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_NormHistogramCostExtractor_getNormFlag_const(self.as_raw_NormHistogramCostExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -297,7 +366,10 @@ pub trait NormHistogramCostExtractor: crate::shape::HistogramCostExtractor + cra
 
 	#[inline]
 	fn set_norm_flag(&mut self, flag: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_NormHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_NormHistogramCostExtractor(), flag) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_NormHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_NormHistogramCostExtractor(), flag, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -316,49 +388,73 @@ pub trait ShapeContextDistanceExtractorConst: crate::shape::ShapeDistanceExtract
 
 	#[inline]
 	fn get_angular_bins(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getAngularBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getAngularBins_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_radial_bins(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getRadialBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getRadialBins_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_inner_radius(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getInnerRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getInnerRadius_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_outer_radius(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getOuterRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getOuterRadius_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_rotation_invariant(&self) -> Result<bool> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getRotationInvariant_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getRotationInvariant_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_shape_context_weight(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getShapeContextWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getShapeContextWeight_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_image_appearance_weight(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getImageAppearanceWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getImageAppearanceWeight_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_bending_energy_weight(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getBendingEnergyWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getBendingEnergyWeight_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -366,32 +462,47 @@ pub trait ShapeContextDistanceExtractorConst: crate::shape::ShapeDistanceExtract
 	fn get_images(&self, image1: &mut dyn core::ToOutputArray, image2: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(image1);
 		output_array_arg!(image2);
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getImages_const_const__OutputArrayR_const__OutputArrayR(self.as_raw_ShapeContextDistanceExtractor(), image1.as_raw__OutputArray(), image2.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getImages_const_const__OutputArrayR_const__OutputArrayR(self.as_raw_ShapeContextDistanceExtractor(), image1.as_raw__OutputArray(), image2.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_iterations(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getIterations_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getIterations_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_cost_extractor(&self) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getCostExtractor_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getCostExtractor_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_std_dev(&self) -> Result<f32> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getStdDev_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getStdDev_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_transform_algorithm(&self) -> Result<core::Ptr<dyn crate::shape::ShapeTransformer>> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getTransformAlgorithm_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_getTransformAlgorithm_const(self.as_raw_ShapeContextDistanceExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::shape::ShapeTransformer>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -408,7 +519,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * nAngularBins: The number of angular bins in the shape context descriptor.
 	#[inline]
 	fn set_angular_bins(&mut self, n_angular_bins: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setAngularBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_angular_bins) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setAngularBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_angular_bins, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -419,7 +533,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * nRadialBins: The number of radial bins in the shape context descriptor.
 	#[inline]
 	fn set_radial_bins(&mut self, n_radial_bins: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setRadialBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_radial_bins) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setRadialBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_radial_bins, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -429,7 +546,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * innerRadius: The value of the inner radius.
 	#[inline]
 	fn set_inner_radius(&mut self, inner_radius: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setInnerRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), inner_radius) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setInnerRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), inner_radius, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -439,13 +559,19 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * outerRadius: The value of the outer radius.
 	#[inline]
 	fn set_outer_radius(&mut self, outer_radius: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setOuterRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), outer_radius) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setOuterRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), outer_radius, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_rotation_invariant(&mut self, rotation_invariant: bool) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setRotationInvariant_bool(self.as_raw_mut_ShapeContextDistanceExtractor(), rotation_invariant) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setRotationInvariant_bool(self.as_raw_mut_ShapeContextDistanceExtractor(), rotation_invariant, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -458,7 +584,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * shapeContextWeight: The weight of the shape context distance in the final distance value.
 	#[inline]
 	fn set_shape_context_weight(&mut self, shape_context_weight: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setShapeContextWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), shape_context_weight) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setShapeContextWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), shape_context_weight, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -473,7 +602,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * imageAppearanceWeight: The weight of the appearance cost in the final distance value.
 	#[inline]
 	fn set_image_appearance_weight(&mut self, image_appearance_weight: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setImageAppearanceWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), image_appearance_weight) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setImageAppearanceWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), image_appearance_weight, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -486,7 +618,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * bendingEnergyWeight: The weight of the Bending Energy in the final distance value.
 	#[inline]
 	fn set_bending_energy_weight(&mut self, bending_energy_weight: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setBendingEnergyWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), bending_energy_weight) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setBendingEnergyWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), bending_energy_weight, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -500,13 +635,19 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	fn set_images(&mut self, image1: &dyn core::ToInputArray, image2: &dyn core::ToInputArray) -> Result<()> {
 		input_array_arg!(image1);
 		input_array_arg!(image2);
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setImages_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeContextDistanceExtractor(), image1.as_raw__InputArray(), image2.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setImages_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeContextDistanceExtractor(), image1.as_raw__InputArray(), image2.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_iterations(&mut self, iterations: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setIterations_int(self.as_raw_mut_ShapeContextDistanceExtractor(), iterations) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setIterations_int(self.as_raw_mut_ShapeContextDistanceExtractor(), iterations, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -517,7 +658,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// matrix between descriptors.
 	#[inline]
 	fn set_cost_extractor(&mut self, mut comparer: core::Ptr<dyn crate::shape::HistogramCostExtractor>) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setCostExtractor_Ptr_HistogramCostExtractor_(self.as_raw_mut_ShapeContextDistanceExtractor(), comparer.as_raw_mut_PtrOfHistogramCostExtractor()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setCostExtractor_Ptr_HistogramCostExtractor_(self.as_raw_mut_ShapeContextDistanceExtractor(), comparer.as_raw_mut_PtrOfHistogramCostExtractor(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -527,7 +671,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * sigma: Standard Deviation.
 	#[inline]
 	fn set_std_dev(&mut self, sigma: f32) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setStdDev_float(self.as_raw_mut_ShapeContextDistanceExtractor(), sigma) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setStdDev_float(self.as_raw_mut_ShapeContextDistanceExtractor(), sigma, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -538,7 +685,10 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// transformation.
 	#[inline]
 	fn set_transform_algorithm(&mut self, mut transformer: core::Ptr<dyn crate::shape::ShapeTransformer>) -> Result<()> {
-		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setTransformAlgorithm_Ptr_ShapeTransformer_(self.as_raw_mut_ShapeContextDistanceExtractor(), transformer.as_raw_mut_PtrOfShapeTransformer()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeContextDistanceExtractor_setTransformAlgorithm_Ptr_ShapeTransformer_(self.as_raw_mut_ShapeContextDistanceExtractor(), transformer.as_raw_mut_PtrOfShapeTransformer(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -565,7 +715,10 @@ pub trait ShapeDistanceExtractor: core::AlgorithmTrait + crate::shape::ShapeDist
 	fn compute_distance(&mut self, contour1: &dyn core::ToInputArray, contour2: &dyn core::ToInputArray) -> Result<f32> {
 		input_array_arg!(contour1);
 		input_array_arg!(contour2);
-		let ret = unsafe { sys::cv_ShapeDistanceExtractor_computeDistance_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeDistanceExtractor(), contour1.as_raw__InputArray(), contour2.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeDistanceExtractor_computeDistance_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeDistanceExtractor(), contour1.as_raw__InputArray(), contour2.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -592,7 +745,10 @@ pub trait ShapeTransformerConst: core::AlgorithmTraitConst {
 	fn warp_image(&self, transforming_image: &dyn core::ToInputArray, output: &mut dyn core::ToOutputArray, flags: i32, border_mode: i32, border_value: core::Scalar) -> Result<()> {
 		input_array_arg!(transforming_image);
 		output_array_arg!(output);
-		let ret = unsafe { sys::cv_ShapeTransformer_warpImage_const_const__InputArrayR_const__OutputArrayR_int_int_const_ScalarR(self.as_raw_ShapeTransformer(), transforming_image.as_raw__InputArray(), output.as_raw__OutputArray(), flags, border_mode, &border_value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeTransformer_warpImage_const_const__InputArrayR_const__OutputArrayR_int_int_const_ScalarR(self.as_raw_ShapeTransformer(), transforming_image.as_raw__InputArray(), output.as_raw__OutputArray(), flags, border_mode, &border_value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -611,7 +767,10 @@ pub trait ShapeTransformer: core::AlgorithmTrait + crate::shape::ShapeTransforme
 	fn estimate_transformation(&mut self, transforming_shape: &dyn core::ToInputArray, target_shape: &dyn core::ToInputArray, matches: &mut core::Vector<core::DMatch>) -> Result<()> {
 		input_array_arg!(transforming_shape);
 		input_array_arg!(target_shape);
-		let ret = unsafe { sys::cv_ShapeTransformer_estimateTransformation_const__InputArrayR_const__InputArrayR_vector_DMatch_R(self.as_raw_mut_ShapeTransformer(), transforming_shape.as_raw__InputArray(), target_shape.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeTransformer_estimateTransformation_const__InputArrayR_const__InputArrayR_vector_DMatch_R(self.as_raw_mut_ShapeTransformer(), transforming_shape.as_raw__InputArray(), target_shape.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -627,7 +786,10 @@ pub trait ShapeTransformer: core::AlgorithmTrait + crate::shape::ShapeTransforme
 	fn apply_transformation(&mut self, input: &dyn core::ToInputArray, output: &mut dyn core::ToOutputArray) -> Result<f32> {
 		input_array_arg!(input);
 		output_array_arg!(output);
-		let ret = unsafe { sys::cv_ShapeTransformer_applyTransformation_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ShapeTransformer(), input.as_raw__InputArray(), output.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ShapeTransformer_applyTransformation_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ShapeTransformer(), input.as_raw__InputArray(), output.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -642,7 +804,10 @@ pub trait ThinPlateSplineShapeTransformerConst: crate::shape::ShapeTransformerCo
 
 	#[inline]
 	fn get_regularization_parameter(&self) -> Result<f64> {
-		let ret = unsafe { sys::cv_ThinPlateSplineShapeTransformer_getRegularizationParameter_const(self.as_raw_ThinPlateSplineShapeTransformer()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ThinPlateSplineShapeTransformer_getRegularizationParameter_const(self.as_raw_ThinPlateSplineShapeTransformer(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -658,7 +823,10 @@ pub trait ThinPlateSplineShapeTransformer: crate::shape::ShapeTransformer + crat
 	/// * beta: value of the regularization parameter.
 	#[inline]
 	fn set_regularization_parameter(&mut self, beta: f64) -> Result<()> {
-		let ret = unsafe { sys::cv_ThinPlateSplineShapeTransformer_setRegularizationParameter_double(self.as_raw_mut_ThinPlateSplineShapeTransformer(), beta) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_ThinPlateSplineShapeTransformer_setRegularizationParameter_double(self.as_raw_mut_ThinPlateSplineShapeTransformer(), beta, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
