@@ -19,10 +19,10 @@
 //! case, a set of patterns  are successively projected onto the measuring surface.
 //! The codeword for a given pixel is usually formed by  the sequence of illuminance values for that
 //! pixel across the projected patterns. Thus, the codification is called  temporal because the bits
-//! of the codewords are multiplexed in time [pattern](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_pattern) .
+//! of the codewords are multiplexed in time [pattern](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_pattern) .
 //! 
 //! In this module a time-multiplexing coding strategy based on Gray encoding is implemented following the
-//! (stereo) approach described in 3DUNDERWORLD algorithm [UNDERWORLD](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_UNDERWORLD) .
+//! (stereo) approach described in 3DUNDERWORLD algorithm [UNDERWORLD](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_UNDERWORLD) .
 //! For more details, see @ref tutorial_structured_light.
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
@@ -34,7 +34,7 @@ pub const DECODE_3D_UNDERWORLD: i32 = 0;
 pub const FAPS: i32 = 2;
 pub const FTP: i32 = 0;
 pub const PSP: i32 = 1;
-/// Class implementing the Gray-code pattern, based on [UNDERWORLD](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_UNDERWORLD).
+/// Class implementing the Gray-code pattern, based on [UNDERWORLD](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_UNDERWORLD).
 /// 
 /// The generation of the pattern images is performed with Gray encoding using the traditional white and black colors.
 /// 
@@ -56,7 +56,10 @@ pub trait GrayCodePatternConst: crate::structured_light::StructuredLightPatternC
 	/// The number of pattern images needed for the graycode pattern.
 	#[inline]
 	fn get_number_of_pattern_images(&self) -> Result<size_t> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_getNumberOfPatternImages_const(self.as_raw_GrayCodePattern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_getNumberOfPatternImages_const(self.as_raw_GrayCodePattern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -73,7 +76,10 @@ pub trait GrayCodePatternConst: crate::structured_light::StructuredLightPatternC
 	fn get_images_for_shadow_masks(&self, black_image: &mut dyn core::ToInputOutputArray, white_image: &mut dyn core::ToInputOutputArray) -> Result<()> {
 		input_output_array_arg!(black_image);
 		input_output_array_arg!(white_image);
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_getImagesForShadowMasks_const_const__InputOutputArrayR_const__InputOutputArrayR(self.as_raw_GrayCodePattern(), black_image.as_raw__InputOutputArray(), white_image.as_raw__InputOutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_getImagesForShadowMasks_const_const__InputOutputArrayR_const__InputOutputArrayR(self.as_raw_GrayCodePattern(), black_image.as_raw__InputOutputArray(), white_image.as_raw__InputOutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -90,7 +96,10 @@ pub trait GrayCodePatternConst: crate::structured_light::StructuredLightPatternC
 	#[inline]
 	fn get_proj_pixel(&self, pattern_images: &dyn core::ToInputArray, x: i32, y: i32, proj_pix: &mut core::Point) -> Result<bool> {
 		input_array_arg!(pattern_images);
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_getProjPixel_const_const__InputArrayR_int_int_PointR(self.as_raw_GrayCodePattern(), pattern_images.as_raw__InputArray(), x, y, proj_pix) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_getProjPixel_const_const__InputArrayR_int_int_PointR(self.as_raw_GrayCodePattern(), pattern_images.as_raw__InputArray(), x, y, proj_pix, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -107,7 +116,10 @@ pub trait GrayCodePattern: crate::structured_light::GrayCodePatternConst + crate
 	/// * value: The desired white threshold value.
 	#[inline]
 	fn set_white_threshold(&mut self, value: size_t) -> Result<()> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_setWhiteThreshold_size_t(self.as_raw_mut_GrayCodePattern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_setWhiteThreshold_size_t(self.as_raw_mut_GrayCodePattern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -119,7 +131,10 @@ pub trait GrayCodePattern: crate::structured_light::GrayCodePatternConst + crate
 	/// * value: The desired black threshold value.
 	#[inline]
 	fn set_black_threshold(&mut self, value: size_t) -> Result<()> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_setBlackThreshold_size_t(self.as_raw_mut_GrayCodePattern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_setBlackThreshold_size_t(self.as_raw_mut_GrayCodePattern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -134,14 +149,20 @@ impl dyn GrayCodePattern + '_ {
 	/// * parameters: GrayCodePattern::Params()
 	#[inline]
 	pub fn create(parameters: &crate::structured_light::GrayCodePattern_Params) -> Result<core::Ptr<dyn crate::structured_light::GrayCodePattern>> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_create_const_ParamsR(parameters.as_raw_GrayCodePattern_Params()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_create_const_ParamsR(parameters.as_raw_GrayCodePattern_Params(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::structured_light::GrayCodePattern>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create_1(width: i32, height: i32) -> Result<core::Ptr<dyn crate::structured_light::GrayCodePattern>> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_create_int_int(width, height) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_create_int_int(width, height, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::structured_light::GrayCodePattern>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -215,7 +236,10 @@ impl crate::structured_light::GrayCodePattern_ParamsTrait for GrayCodePattern_Pa
 impl GrayCodePattern_Params {
 	#[inline]
 	pub fn default() -> Result<crate::structured_light::GrayCodePattern_Params> {
-		let ret = unsafe { sys::cv_structured_light_GrayCodePattern_Params_Params() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_GrayCodePattern_Params_Params(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::structured_light::GrayCodePattern_Params::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -223,7 +247,7 @@ impl GrayCodePattern_Params {
 }
 
 /// Class implementing Fourier transform profilometry (FTP) , phase-shifting profilometry (PSP)
-/// and Fourier-assisted phase-shifting profilometry (FAPS) based on [faps](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_faps).
+/// and Fourier-assisted phase-shifting profilometry (FAPS) based on [faps](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_faps).
 /// 
 /// This class generates sinusoidal patterns that can be used with FTP, PSP and FAPS.
 pub trait SinusoidalPatternConst: crate::structured_light::StructuredLightPatternConst {
@@ -250,7 +274,10 @@ pub trait SinusoidalPattern: crate::structured_light::SinusoidalPatternConst + c
 		output_array_arg!(wrapped_phase_map);
 		output_array_arg!(shadow_mask);
 		input_array_arg!(fundamental);
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_computePhaseMap_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), pattern_images.as_raw__InputArray(), wrapped_phase_map.as_raw__OutputArray(), shadow_mask.as_raw__OutputArray(), fundamental.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_computePhaseMap_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), pattern_images.as_raw__InputArray(), wrapped_phase_map.as_raw__OutputArray(), shadow_mask.as_raw__OutputArray(), fundamental.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -268,7 +295,10 @@ pub trait SinusoidalPattern: crate::structured_light::SinusoidalPatternConst + c
 		input_array_arg!(wrapped_phase_map);
 		output_array_arg!(unwrapped_phase_map);
 		input_array_arg!(shadow_mask);
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_unwrapPhaseMap_const__InputArrayR_const__OutputArrayR_Size_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), wrapped_phase_map.as_raw__InputArray(), unwrapped_phase_map.as_raw__OutputArray(), cam_size.opencv_as_extern(), shadow_mask.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_unwrapPhaseMap_const__InputArrayR_const__OutputArrayR_Size_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), wrapped_phase_map.as_raw__InputArray(), unwrapped_phase_map.as_raw__OutputArray(), cam_size.opencv_as_extern(), shadow_mask.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -282,7 +312,10 @@ pub trait SinusoidalPattern: crate::structured_light::SinusoidalPatternConst + c
 		input_array_arg!(proj_unwrapped_phase_map);
 		input_array_arg!(cam_unwrapped_phase_map);
 		output_array_arg!(matches);
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_findProCamMatches_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_SinusoidalPattern(), proj_unwrapped_phase_map.as_raw__InputArray(), cam_unwrapped_phase_map.as_raw__InputArray(), matches.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_findProCamMatches_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_SinusoidalPattern(), proj_unwrapped_phase_map.as_raw__InputArray(), cam_unwrapped_phase_map.as_raw__InputArray(), matches.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -296,7 +329,10 @@ pub trait SinusoidalPattern: crate::structured_light::SinusoidalPatternConst + c
 		input_array_arg!(pattern_images);
 		output_array_arg!(data_modulation_term);
 		input_array_arg!(shadow_mask);
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_computeDataModulationTerm_const__InputArrayR_const__OutputArrayR_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), pattern_images.as_raw__InputArray(), data_modulation_term.as_raw__OutputArray(), shadow_mask.as_raw__InputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_computeDataModulationTerm_const__InputArrayR_const__OutputArrayR_const__InputArrayR(self.as_raw_mut_SinusoidalPattern(), pattern_images.as_raw__InputArray(), data_modulation_term.as_raw__OutputArray(), shadow_mask.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -311,7 +347,10 @@ impl dyn SinusoidalPattern + '_ {
 	/// * parameters: makePtr<SinusoidalPattern::Params>()
 	#[inline]
 	pub fn create(mut parameters: core::Ptr<crate::structured_light::SinusoidalPattern_Params>) -> Result<core::Ptr<dyn crate::structured_light::SinusoidalPattern>> {
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_create_Ptr_Params_(parameters.as_raw_mut_PtrOfSinusoidalPattern_Params()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_create_Ptr_Params_(parameters.as_raw_mut_PtrOfSinusoidalPattern_Params(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::structured_light::SinusoidalPattern>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -482,7 +521,10 @@ impl crate::structured_light::SinusoidalPattern_ParamsTrait for SinusoidalPatter
 impl SinusoidalPattern_Params {
 	#[inline]
 	pub fn default() -> Result<crate::structured_light::SinusoidalPattern_Params> {
-		let ret = unsafe { sys::cv_structured_light_SinusoidalPattern_Params_Params() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_SinusoidalPattern_Params_Params(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::structured_light::SinusoidalPattern_Params::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -513,7 +555,10 @@ pub trait StructuredLightPatternConst: core::AlgorithmTraitConst {
 		output_array_arg!(disparity_map);
 		input_array_arg!(black_images);
 		input_array_arg!(white_images);
-		let ret = unsafe { sys::cv_structured_light_StructuredLightPattern_decode_const_const_vector_vector_Mat__R_const__OutputArrayR_const__InputArrayR_const__InputArrayR_int(self.as_raw_StructuredLightPattern(), pattern_images.as_raw_VectorOfVectorOfMat(), disparity_map.as_raw__OutputArray(), black_images.as_raw__InputArray(), white_images.as_raw__InputArray(), flags) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_StructuredLightPattern_decode_const_const_vector_vector_Mat__R_const__OutputArrayR_const__InputArrayR_const__InputArrayR_int(self.as_raw_StructuredLightPattern(), pattern_images.as_raw_VectorOfVectorOfMat(), disparity_map.as_raw__OutputArray(), black_images.as_raw__InputArray(), white_images.as_raw__InputArray(), flags, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -529,7 +574,10 @@ pub trait StructuredLightPattern: core::AlgorithmTrait + crate::structured_light
 	#[inline]
 	fn generate(&mut self, pattern_images: &mut dyn core::ToOutputArray) -> Result<bool> {
 		output_array_arg!(pattern_images);
-		let ret = unsafe { sys::cv_structured_light_StructuredLightPattern_generate_const__OutputArrayR(self.as_raw_mut_StructuredLightPattern(), pattern_images.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_structured_light_StructuredLightPattern_generate_const__OutputArrayR(self.as_raw_mut_StructuredLightPattern(), pattern_images.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
