@@ -4,9 +4,9 @@
 template struct Result<void*>;
 
 extern "C" {
-	Result<void*> cv_ORB_create() {
+	void cv_ORB_create(Result<void*>* ocvrs_return) {
 		try {
-			return Ok<void*>(new cv::Ptr<cv::ORB>(cv::ORB::create()));
+			return Ok<void*>(new cv::Ptr<cv::ORB>(cv::ORB::create()), ocvrs_return);
 		} OCVRS_CATCH(Result<void*>)
 	}
 }
